import pandas as pd
from sklearn.preprocessing import StandardScaler

class Preprocessor:
  def __init__(self, data: pd.DataFrame):
    self.data = data
  
  def infer_data_types(self, df):
    for col in df.columns:
      if df[col].dtype == 'object':
        # Check for datetime columns
        try:
          pd.to_datetime(df[col], format="%Y/%m/%d")
          df[col] = pd.to_datetime(df[col], errors='coerce')
        except (ValueError, TypeError):
          pass
      
      # Fill in NaN values with the mode (mode frequent value) if applicable
      if df[col].dtype == 'object':
        df[col] = df[col].astype('string')
      elif df[col].dtype in ['float64', 'int64']:
        df[col] = pd.to_numeric(df[col], errors='coerce')
    
    return df
  
  def normalize_data(self):
    scaler = StandardScaler()
    self.data = pd.DataFrame(scaler.fit_transform(self.data), columns=self.data.columns)

    return self.data
  
  def encode_categorical(self):
    self.data = pd.get_dummies(self.data)

    return self.data



import pandas as pd

class Validator:
  def __init__(self, data: pd.DataFrame):
    self.data = data
  
  def validate_data_types(self):
    # Check for consistent data types
    pass

  def check_missing_values(self):
    # Identify missing values in the dataset
    return self.data.isnull().sum()



import pandas as pd
from .validator import Validator
from .preprocessor import Preprocessor

class DataCleaner:
  def __init__(self, data: pd.DataFrame):
    self.data = data
    self.validator = Validator(data)
    self.preprocessor = Preprocessor(data)
  
  def remove_duplicates(self):
    self.data = self.data.drop_duplicates()

    return self.data
  
  def remove_na(self):
    self.data = self.data.dropna()

    return self.data
  
  def clean_data(self):
    self.validator.check_missing_values()
    
    self.data = self.preprocessor.normalize_data()

    return self.data



def AutoClean():
  print('This project has just started!')
  print('It is actively being worked on...')
  print('As of right now I have only published this project to reserve the name')
  print('Sorry for the inconvience')

if __name__ == '__main__':
  AutoClean()



import unittest
import pandas as pd
from sanitipy.data_cleaner import DataCleaner

class TestDataCleaner(unittest.TestCase):
  def test_remove_duplicates(self):
    data = pd.DataFrame({
      'A': [1, 1, 2, 2],
      'B': [3, 3, 4, 4]
    })
    cleaner = DataCleaner(data)
    cleaned_data = cleaner.remove_duplicates()
    
    self.assertEqual(len(cleaned_data), 2)

if __name__ == '__main__':
  unittest.main()
